'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _ = require('./..');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @category communication
 * @component popover
 * @variations collab-ui-react
 */

var Popover = function (_React$Component) {
  (0, _inherits3.default)(Popover, _React$Component);

  function Popover() {
    var _temp, _this, _ret;

    (0, _classCallCheck3.default)(this, Popover);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = (0, _possibleConstructorReturn3.default)(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = {
      isOpen: false
    }, _this.delayedHide = function () {
      if (_this.showTimerId) {
        clearTimeout(_this.showTimerId);
        _this.showTimerId = null;
      }

      var delay = _this.props.hideDelay ? _this.props.hideDelay : _this.props.delay;

      _this.hideTimerId = setTimeout(function () {
        _this.hideTimerId = null;
        _this.setState({ isOpen: false });
      }, delay);
    }, _this.delayedShow = function () {
      if (_this.hideTimerId) {
        clearTimeout(_this.hideTimerId);
        _this.hideTimerId = null;
      }

      var delay = _this.props.showDelay ? _this.props.showDelay : _this.props.delay;

      _this.showTimerId = setTimeout(function () {
        _this.showTimerId = null;
        _this.setState({ isOpen: true });
      }, delay);
    }, _this.handleToggle = function () {
      _this.setState({
        isOpen: !_this.state.isOpen
      });
    }, _this.handleClose = function () {
      _this.setState({ isOpen: false });
    }, _this.handleMouseEnter = function (e) {
      return !_this.showTimerId && !_this.state.isOpen && _this.delayedShow(e);
    }, _this.handleMouseLeave = function (e) {
      if (_this.hasFocus) {
        return false;
      }

      return !_this.hideTimerId && _this.state.isOpen && _this.delayedHide(e);
    }, _this.handleBlur = function (e) {
      _this.hasFocus = false;

      return !_this.hideTimerId && _this.state.isOpen && _this.delayedHide(e);
    }, _this.handleFocus = function (e) {
      _this.hasFocus = true;

      return !_this.showTimerId && !_this.state.isOpen && _this.delayedShow(e);
    }, _temp), (0, _possibleConstructorReturn3.default)(_this, _ret);
  }

  Popover.prototype.componentWillUnmount = function componentWillUnmount() {
    this.hideTimerId && clearTimeout(this.hideTimerId);
    this.showTimerId && clearTimeout(this.showTimerId);
  };

  Popover.prototype.render = function render() {
    var _this2 = this;

    var isOpen = this.state.isOpen;
    var _props = this.props,
        children = _props.children,
        popoverTrigger = _props.popoverTrigger,
        className = _props.className,
        showArrow = _props.showArrow,
        direction = _props.direction,
        content = _props.content,
        closeOnClick = _props.closeOnClick;


    var getTriggers = function getTriggers() {
      var triggerProps = {};
      triggerProps.ref = function (ele) {
        return _this2.anchorRef = ele;
      };
      triggerProps.key = 'child-1';

      switch (popoverTrigger) {

        case 'MouseEnter':
          triggerProps.onMouseEnter = _this2.handleMouseEnter;
          triggerProps.onMouseLeave = _this2.handleMouseLeave;

          triggerProps.onFocus = _this2.handleFocus;
          triggerProps.onBlur = _this2.handleBlur;
          break;

        case 'Click':
          triggerProps.onClick = _this2.handleToggle;
          break;

        case 'Focus':
          triggerProps.onFocus = _this2.handleFocus;
          triggerProps.onBlur = _this2.handleBlur;
          break;
      }

      return triggerProps;
    };

    var anchorWithTriggers = children && _react2.default.cloneElement(children, getTriggers());

    return _react2.default.createElement(
      'div',
      null,
      anchorWithTriggers,
      _react2.default.createElement(
        _.EventOverlay,
        {
          allowClickAway: true,
          anchorNode: this.anchorRef,
          isOpen: isOpen,
          className: className,
          showArrow: showArrow,
          direction: direction,
          close: this.handleClose,
          closeOnClick: closeOnClick
        },
        content
      )
    );
  };

  return Popover;
}(_react2.default.Component);

Popover.displayName = 'Popover';


Popover.defaultProps = {
  className: '',
  direction: 'top-center',
  popoverTrigger: 'MouseEnter',
  showArrow: true,
  showDelay: 0,
  hideDelay: 0,
  delay: 0,
  closeOnClick: false
};

exports.default = Popover;

/**
* @name Popover Default with Delay
*
* @category communication
* @component popover
* @section default
*
* @js

 import {
  Button
} from '@collab-ui/react';

 export default function Default() {
 const content = (
      <span key="1" style={{ padding: '10px'}}>Popover bottom</span>
    );
  return(
    <div className='row'>
      <div>
        <Popover
        content={content}
        direction={'bottom-center'}
        delay={200}
        popoverTrigger={'MouseEnter'}>
          <Button
            children='Hover'
            ariaLabel='Hover'
            color='primary'
            onClick={()=>{}}
          />
        </Popover>
      </div>
      <br />
    </div>
  );
}
**/

/**
* @name Popover on Click
*
* @category communication
* @component popover
* @section onclick
*
* @js

 import {
  Button
} from '@collab-ui/react';

 export default function PopOverClick() {
 const content = (
      <span key="1" style={{ padding: '10px'}}>Popover top</span>
    );
  return(
    <div className='row'>
      <br />
      <div>
        <Popover
        content={content}
        direction={'top-center'}
        popoverTrigger={'Click'}>
          <Button
            children='Click'
            ariaLabel='Click'
            color='primary'
            onClick={()=>{}}
          />
        </Popover>
      </div>
      <br />
    </div>
  );
}
**/

/**
* @name Popover on Focus
*
* @category communication
* @component popover
* @section onfocus
*
* @js

 import {
  Button
} from '@collab-ui/react';

 export default function PopOverFocus() {
 const content = (
      <span key="1" style={{ padding: '10px'}}>Popover right</span>
    );
  return(
    <div className='row'>
    <br />
      <div>
        <Popover
        content={content}
        direction={'right-center'}
        popoverTrigger={'Focus'}>
          <Button
            children='Focus'
            ariaLabel='Focus'
            color='primary'
            onClick={()=>{}}
          />
        </Popover>
      </div>
      <br />
    </div>
  );
}
**/

module.exports = exports['default'];